function out = imgnorm(in,max_levels)
% IMGNORM Image normalization.
%
% Synopsis:
%  out = imgnorm(in,max_levels)
%
% Description:
%  It applies the histogram equalization with 
%  max_level bins. The gray-levels of the resulting
%  texture are renumbered to 1:max_level.
%
% Inputs:
%  in [w x h] Input image int8.
%  Max_Levels [1x1] Number gray-scale levels.
%
% Output:
%  out [w x h] Normalized image.
%

% Modifications:
% 10-aug-2004, VF

im_size = size(in);
in = reshape(in,prod(im_size),1);

in = histeq(in,max_levels);

levels = unique(in);
out = zeros(size(in));
for i = 1:length(levels),
  inx = find(levels(i)==in);
  out(inx) = i;
end

out = reshape(out,im_size(1),im_size(2));

return;

